@@ -71,9 +71,10 @@ class BaseRustSocket:
         Opens the connection to the Rust Server
         """
         try:
-            self.remote.connect()
-            await self._send_wakeup_request()
-            await self.heartbeat.start_beat()
+            if self.remote.ws is None:
+                self.remote.connect()
+                await self._send_wakeup_request()
+                await self.heartbeat.start_beat()
         except ConnectionRefusedError:
             raise ServerNotResponsiveError("Cannot Connect")
 
@@ -96,7 +97,7 @@ class BaseRustSocket:
         await self._handle_ratelimit()
 
         app_request = self._generate_protobuf()
-        app_request.checkSubscription.CopyFrom(AppEmpty())
+        app_request.getTime.CopyFrom(AppEmpty())
 
         self.remote.ignored_responses.append(app_request.seq)
 
