@@ -1,29 +1,32 @@
 import time
 import asyncio
 import logging
-from datetime import datetime
 
-from .rustws import RustWsClient
+from .rustws import RustWebsocket
 from .rustplus_pb2 import *
 from .event_handler import EventHandler
 from .token_bucket import RateLimiter
 from ...commands import CommandHandler
 from ...exceptions import ClientNotConnectedError, ResponseNotRecievedError, RequestError
 
+
 class RustRemote:
 
-    def __init__(self, ip, port, command_options, ratelimit_limit, ratelimit_refill, websocket_length = 600) -> None:
+    def __init__(self, ip, port, command_options, ratelimit_limit, ratelimit_refill, websocket_length=600) -> None:
 
         self.ip = ip
-        self.port = port 
+        self.port = port
         self.command_options = command_options
         self.ratelimit_limit = ratelimit_limit
         self.ratelimit_refill = ratelimit_refill
         self.ratelimiter = RateLimiter(ratelimit_limit, ratelimit_limit, 1, ratelimit_refill)
-        self.open = False
+        self.ws = None
+        self.is_pending = False
         self.websocket_length = websocket_length
         self.responses = {}
         self.ignored_responses = []
+        self.pending_requests = {}
+        self.sent_requests = []
 
         if command_options is None:
             self.use_commands = False
@@ -36,58 +39,59 @@ class RustRemote:
 
     def connect(self) -> None:
 
-        while True:
-            try:
-                self.ws = RustWsClient(ip=self.ip, port=self.port, remote=self)
-                self.ws.daemon = True
-                self.ws.connect()
-                self.open = True
-                break
-            except:
-                logging.getLogger("rustplus.py").warn(f"{datetime.now().strftime('%d/%m/%Y %H:%M:%S')} Cannot Connect to server. Retrying in 20 seconds")
-                time.sleep(20)
+        self.ws = RustWebsocket(ip=self.ip, port=self.port, remote=self)
+        self.ws.connect()
 
     def close(self) -> None:
 
         if self.ws is not None:
             self.ws.close()
-            self.ws.terminate()
             del self.ws
             self.ws = None
-            self.open = False
 
-    async def send_message(self, request : AppRequest) -> None:
+    async def send_message(self, request: AppRequest) -> None:
 
-        try:
-           await self.sock().send_message(request)
-        except:
-            self.close()
-            self.connect()
-            return self.send_message(request)
+        self.ws.send_message(request)
 
-    async def get_response(self, seq : int, app_request : AppRequest, retry_depth : int = 10) -> AppMessage:
+    async def get_response(self, seq: int, app_request: AppRequest) -> AppMessage:
         """
-        Returns a given response from the server. After 2 seconds throws Exception as response is assumed to not be coming
+        Returns a given response from the server.
         """
 
         attempts = 0
-        while seq not in self.responses:
 
-            if attempts == 100:
-                if retry_depth != 0:
+        while seq in self.pending_requests:
+
+            if seq in self.sent_requests:
+
+                if attempts <= 40:
+
+                    attempts += 1
+                    await asyncio.sleep(0.1)
+
+                else:
 
                     await self.send_message(app_request)
-                    return await self.get_response(seq, app_request, retry_depth=retry_depth-1)
+                    await asyncio.sleep(1)
+                    attempts = 0
 
-                raise ResponseNotRecievedError("Not Recieved")
+            if attempts <= 10:
+                await asyncio.sleep(0.1)
+                attempts += 1
 
-            attempts += 1
-            await asyncio.sleep(0.1)
+            else:
+                await self.send_message(app_request)
+                await asyncio.sleep(1)
+                attempts = 0
+
+        if seq not in self.responses:
+            raise ResponseNotRecievedError("Not Recieved")
 
         response = self.responses.pop(seq)
 
         if response.response.error.error == "rate_limit":
-            logging.getLogger("rustplus.py").warn("[Rustplus.py] RateLimit Exception Occurred. Retrying after bucket is full")
+            logging.getLogger("rustplus.py").warning(
+                "[Rustplus.py] RateLimit Exception Occurred. Retrying after bucket is full")
 
             # Fully Refill the bucket
 
@@ -110,26 +114,23 @@ class RustRemote:
                 await asyncio.sleep(self.ratelimiter.get_estimated_delay_time(cost))
 
             await self.send_message(app_request)
-            response = await self.get_response(seq, app_request, False)
-        
-        elif self.ws._error_present(response.response.error.error):
+            response = await self.get_response(seq, app_request)
+
+        elif self.ws.error_present(response.response.error.error):
             raise RequestError(response.response.error.error)
 
         return response
 
-    def sock(self) -> RustWsClient:
+    def _sock(self) -> RustWebsocket:
 
         if self.ws is None:
-            if not self.open:
-                raise ClientNotConnectedError("No Current Websocket Connection")
-            else:
-                self.connect()
+            raise ClientNotConnectedError("No Current Websocket Connection")
+
+        while self.is_pending:
+            time.sleep(1)
 
         if time.time() - self.ws.connected_time >= self.websocket_length:
             self.close()
             self.connect()
 
-        if self.ws is None:
-            return self.sock()
-
         return self.ws
